from typing import List, Union
from pydantic import AnyHttpUrl, validator
from pydantic_settings import BaseSettings
from pathlib import Path


class Settings(BaseSettings):
    API_V1_STR: str = "/api/v1"
    PROJECT_NAME: str = "TechDating API"
    PROJECT_DESCRIPTION: str = "API for a dating app focused on tech professionals"
    VERSION: str = "0.1.0"
    
    # Security
    SECRET_KEY: str = "CHANGE_ME_IN_PRODUCTION"
    ALGORITHM: str = "HS256"
    ACCESS_TOKEN_EXPIRE_MINUTES: int = 30
    
    # CORS
    BACKEND_CORS_ORIGINS: List[AnyHttpUrl] = []

    @validator("BACKEND_CORS_ORIGINS", pre=True)
    def assemble_cors_origins(cls, v: Union[str, List[str]]) -> Union[List[str], str]:
        if isinstance(v, str) and not v.startswith("["):
            return [i.strip() for i in v.split(",")]
        elif isinstance(v, (list, str)):
            return v
        raise ValueError(v)
    
    # Database
    DB_DIR: Path = Path("/app") / "storage" / "db"
    
    # Other settings
    DEBUG: bool = True
    
    class Config:
        case_sensitive = True
        env_file = ".env"


settings = Settings()

# Ensure the database directory exists
settings.DB_DIR.mkdir(parents=True, exist_ok=True)